@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "eldc" "0.5.0"
+(define-package "eldc" "20260130.1628"
   "Emacs Lisp Dictionary Converter."
   '((emacs    "25.1")
     (deferred "0.5.1"))
